From 4964ac4a656521a0e84615ea718c81fb4e95bedf Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Rudolf=20Adamkovi=C4=8D?= <salutis@me.com>
Date: Thu, 25 May 2023 17:21:38 +0200
Subject: [PATCH 2/2] emacs: re-layout notmuch-hello when window width changes

---
 emacs/notmuch-hello.el | 22 +++++++++++++++++++---
 1 file changed, 19 insertions(+), 3 deletions(-)

diff --git a/emacs/notmuch-hello.el b/emacs/notmuch-hello.el
index 3235f555..f245a7dd 100644
--- a/emacs/notmuch-hello.el
+++ b/emacs/notmuch-hello.el
@@ -383,6 +383,10 @@ supported for \"Customized queries section\" items."
 (defvar notmuch-hello-first-run t
   "True if `notmuch-hello' is run for the first time, set to nil afterwards.")
 
+(defvar notmuch-hello-scheduled-to-run nil
+  "True if `notmuch-hello' is scheduled to run during the next
+re-display, and set to nil afterwards.")
+
 ;;; Widgets for inserters
 
 (define-widget 'notmuch-search-item 'item
@@ -701,12 +705,23 @@ with `notmuch-hello-query-counts'."
 	    ;; The user just switched to hello in this window (hello
 	    ;; is currently visible, was not visible on the last
 	    ;; configuration change, and this is not a new window)
-	    (setq do-refresh t)))))
-    (when (and do-refresh notmuch-hello-auto-refresh)
+	    (setq do-refresh t)))
+	(when (eq cur-buf hello-buf)
+	  ;; This is the hello buffer, so check its last and current width.
+	  (let ((last-width (window-parameter window 'notmuch-hello-last-width))
+		(cur-width (window-width window)))
+	    (unless (equal last-width cur-width)
+	      ;; The with of the window has changed, so do refresh.
+	      (set-window-parameter window 'notmuch-hello-last-width cur-width)
+	      (setq do-refresh t))))))
+    (when (and do-refresh
+	       notmuch-hello-auto-refresh
+	       (not notmuch-hello-scheduled-to-run))
       ;; Refresh hello as soon as we get back to redisplay.  On Emacs
       ;; 24, we can't do it right here because something in this
       ;; hook's call stack overrides hello's point placement.
       ;; FIXME And on Emacs releases that we still support?
+      (setq notmuch-hello-scheduled-to-run t)
       (run-at-time nil nil #'notmuch-hello t))
     (unless hello-buf
       ;; Clean up hook
@@ -1014,7 +1029,8 @@ following:
     (forward-line (1- target-line))
     (move-to-column target-column))
   (run-hooks 'notmuch-hello-refresh-hook)
-  (setq notmuch-hello-first-run nil))
+  (setq notmuch-hello-first-run nil
+	notmuch-hello-scheduled-to-run nil))
 
 ;;; _
 
-- 
2.37.1 (Apple Git-137.1)

